==> mahara_1.0.4.orig.tar.gz: mahara-1.0.4/htdocs/artefact/resume/lang/en.utf8/artefact.resume.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage artefact-resume
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Resumé';

$string['myresume'] = 'My Resumé';
$string['mygoals'] = 'My Goals';
$string['myskills'] = 'My Skills';
$string['coverletter'] = 'Cover Letter';
$string['interest'] = 'Interests';
$string['contactinformation'] = 'Contact Information';
$string['personalinformation'] = 'Personal Information';
$string['dateofbirth'] = 'Date of birth';
$string['placeofbirth'] = 'Place of birth';
$string['citizenship'] = 'Citizenship';
$string['visastatus'] = 'Visa Status';
$string['female'] = 'Female';
$string['male'] = 'Male';
$string['gender'] = 'Gender';
$string['maritalstatus'] = 'Marital Status';
$string['resumesaved'] = 'Resumé saved';
$string['resumesavefailed'] = 'Failed to update your resumé';
$string['educationhistory'] = 'Education History';
$string['employmenthistory'] = 'Employment History';
$string['certification'] = 'Certifications, Accreditations, and Awards';
$string['book'] = 'Books and Publications';
$string['membership'] = 'Professional Memberships';
$string['startdate'] = 'Start date';
$string['enddate'] = 'End date';
$string['date'] = 'Date';
$string['position'] = 'Position';
$string['qualification'] = 'Qualification';
$string['description'] = 'Description';
$string['title'] = 'Title';
$string['employer'] = 'Employer';
$string['jobtitle'] = 'Job Title';
$string['jobdescription'] = 'Position Description';
$string['institution'] = 'Institution';
$string['qualtype'] = 'Qualification Type';
$string['qualname'] = 'Qualification Name';
$string['qualdescription'] = 'Qualification Description';
$string['contribution'] = 'Contribution';
$string['compositedeleteconfirm'] = 'Are you sure you want to delete this?';
$string['compositesaved'] = 'Saved successfully';
$string['compositesavefailed'] = 'Save failed';
$string['compositedeleted'] = 'Deleted successfully';
$string['backtoresume'] = 'Back to My Resumé';
$string['personalgoal'] = 'Personal Goals';
$string['academicgoal'] = 'Academic Goals';
$string['careergoal'] = 'Career Goals';
$string['personalskill'] = 'Personal Skills';
$string['academicskill'] = 'Academic Skills';
$string['workskill'] = 'Work Skills';
$string['goalandskillsaved'] = 'Saved successfully';
$string['resume'] = 'Resumé';
$string['current'] = 'Current';
$string['moveup'] = 'Move Up';
$string['movedown'] = 'Move Down';
?>

==> mahara_1.2.7.orig.tar.gz: mahara-1.2.7/htdocs/artefact/resume/lang/en.utf8/artefact.resume.php <==
<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage artefact-resume
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Resumé';

$string['myresume'] = 'My Resumé';
$string['mygoals'] = 'My Goals';
$string['myskills'] = 'My Skills';
$string['coverletter'] = 'Cover Letter';
$string['interest'] = 'Interests';
$string['contactinformation'] = 'Contact Information';
$string['personalinformation'] = 'Personal Information';
$string['dateofbirth'] = 'Date of birth';
$string['placeofbirth'] = 'Place of birth';
$string['citizenship'] = 'Citizenship';
$string['visastatus'] = 'Visa Status';
$string['female'] = 'Female';
$string['male'] = 'Male';
$string['gender'] = 'Gender';
$string['maritalstatus'] = 'Marital Status';
$string['resumesaved'] = 'Resumé saved';
$string['resumesavefailed'] = 'Failed to update your resumé';
$string['educationhistory'] = 'Education History';
$string['employmenthistory'] = 'Employment History';
$string['certification'] = 'Certifications, Accreditations, and Awards';
$string['book'] = 'Books and Publications';
$string['membership'] = 'Professional Memberships';
$string['startdate'] = 'Start date';
$string['enddate'] = 'End date';
$string['date'] = 'Date';
$string['position'] = 'Position';
$string['qualification'] = 'Qualification';
$string['title'] = 'Title';
$string['description'] = 'Description';
$string['employer'] = 'Employer';
$string['jobtitle'] = 'Job Title';
$string['jobdescription'] = 'Position Description';
$string['institution'] = 'Institution';
$string['qualtype'] = 'Qualification Type';
$string['qualname'] = 'Qualification Name';
$string['qualdescription'] = 'Qualification Description';
$string['contribution'] = 'Contribution';
$string['detailsofyourcontribution'] = 'Details of your contribution';
$string['compositedeleteconfirm'] = 'Are you sure you want to delete this?';
$string['compositesaved'] = 'Saved successfully';
$string['compositesavefailed'] = 'Save failed';
$string['compositedeleted'] = 'Deleted successfully';
$string['backtoresume'] = 'Back to My Resumé';
$string['personalgoal'] = 'Personal Goals';
$string['academicgoal'] = 'Academic Goals';
$string['careergoal'] = 'Career Goals';
$string['personalskill'] = 'Personal Skills';
$string['academicskill'] = 'Academic Skills';
$string['workskill'] = 'Work Skills';
$string['goalandskillsaved'] = 'Saved successfully';
$string['resume'] = 'Resumé';
$string['current'] = 'Current';
$string['moveup'] = 'Move Up';
$string['movedown'] = 'Move Down';
$string['viewyourresume'] = 'View your Resumé';
$string['resumeofuser'] = 'Resumé of %s';

?>
